@@ -27,8 +27,8 @@
 ;;; Code:
 (require 'cl-lib)
 (require 'map)
-(require 'gptel)
 (require 'mail-parse)
+(eval-and-compile (require 'gptel-request))
 
 (declare-function gptel-context--collect-media "gptel-context")
 (declare-function gptel-context--wrap "gptel-context")
@@ -533,7 +533,8 @@ Convenient to use with `cl-multiple-value-bind'"
 
 (defvar gptel-bedrock--model-ids
   ;; https://docs.aws.amazon.com/bedrock/latest/userguide/models-supported.html
-  '((claude-opus-4-6             . "anthropic.claude-opus-4-6-v1")
+  '((claude-sonnet-4-6           . "anthropic.claude-sonnet-4-6")
+    (claude-opus-4-6             . "anthropic.claude-opus-4-6-v1")
     (claude-sonnet-4-5-20250929  . "anthropic.claude-sonnet-4-5-20250929-v1:0")
     (claude-haiku-4-5-20251001   . "anthropic.claude-haiku-4-5-20251001-v1:0")
 	(claude-opus-4-5-20251101    . "anthropic.claude-opus-4-5-20251101-v1:0")
